@@ -4,6 +4,6 @@ from django.contrib import admin
 
 
 class CloudStackBundleAdmin(admin.ModelAdmin):
-    search_fields = ("name", "region")
+    search_fields = ("name", "region__name")
     list_display = ("name","zoneid", "templateid", "networkid", "region")
     save_on_top = True
