@@ -4,6 +4,6 @@ from django.contrib import admin
 
 
 class CloudStackServiceofferingAdmin(admin.ModelAdmin):
-    search_fields = ("name", "region")
+    search_fields = ("name", "region__name")
     list_display = ("serviceofferingid", "name", "region")
     save_on_top = True
